@@ -459,13 +459,12 @@ use vars qw( @ISA );
 
 sub _getData {
     my $self = shift;
-    my $data = $self->getNodeValue(@_);
-    return $data =~ m/\s+(.*)/ ? $1 : "";
+    return $self->getNodeValue(@_);
 }
 
 sub _setData {
     my ($self, $data) = shift;
-    $self->setNodeValue($self->target(@_)." ".$data, @_);
+    $self->setNodeValue($data, @_);
 }
 
 sub data {
@@ -477,9 +476,7 @@ sub data {
 
 sub target {
     my $self = shift;
-    my $tmp = $self->getNodeValue(@_);
-    $tmp =~ m/^\S*/;
-    return $&;
+    return $self->getNodeName(@_);
 }
 
 #################### Comment ####################
@@ -1578,6 +1575,32 @@ The situation to be used (optional).
 
 =back
 
+=head2 xql_ns
+
+Executes the XPath expression and returns the ARRAYREF of resulting
+nodes.
+Not in DOM spec.
+
+B<Synopsis:>
+
+  $node->xql($expr, $nsmap [, $situa]);
+
+=over 4
+
+=item $expr
+
+The expression to be replaced.
+
+=item $nsmap
+
+Hashref to namespace mappings like { prefix => uri, ...}
+
+=item $situa
+
+The situation to be used (optional).
+
+=back
+
 =head1 XML::Sablotron::DOM::Document
 
 Represents the whole DOM document (the "/" root element).
